@@ -16,7 +16,7 @@
 #
 ''' Provides the different actions that can be performed by layman.'''
 
-__version__ = "$Id: action.py 285 2007-01-05 08:49:14Z wrobel $"
+__version__ = "$Id: action.py 310 2007-04-09 16:30:40Z wrobel $"
 
 #===============================================================================
 #
@@ -24,6 +24,8 @@ __version__ = "$Id: action.py 285 2007-01-05 08:49:14Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
+import sys
+
 from   layman.db                import DB, RemoteDB
 
 from   layman.debug             import OUT
@@ -48,6 +50,7 @@ class Fetch:
     ...           'quietness':3}
     >>> a = Fetch(config)
     >>> a.run()
+    0
     >>> b = open(a.db.path(config['overlays']))
     >>> b.readlines()[24]
     '      A collection of ebuilds from Gunnar Wrobel [wrobel@gentoo.org].\\n'
@@ -70,6 +73,8 @@ class Fetch:
             OUT.die('Failed to fetch overlay list!\nError was: '
                     + str(error))
 
+        return 0
+
 #===============================================================================
 #
 # Class Sync
@@ -120,12 +125,14 @@ class Sync:
             OUT.info('\nSuccess:\n------\n', 3)
             for i in success:
                 OUT.info(i, 3)
-
+                
         if warnings:
             OUT.warn('\nErrors:\n------\n', 2)
             for i in warnings:
                 OUT.warn(i + '\n', 2)
+            return 1
 
+        return 0
 
 #===============================================================================
 #
@@ -154,6 +161,8 @@ class Add:
 
         OUT.debug('Adding selected overlays', 6)
 
+        result = 0
+
         for i in self.selection:
             overlay = self.rdb.select(i)
 
@@ -166,8 +175,12 @@ class Add:
                 except Exception, error:
                     OUT.warn('Failed to add overlay "' + i + '".\nError was: '
                              + str(error), 2)
+                    result = 1
             else:
                 OUT.warn('Overlay "' + i + '" does not exist!', 2)
+                result = 1
+
+        return result
 
 #===============================================================================
 #
@@ -192,6 +205,8 @@ class Delete:
 
         OUT.debug('Deleting selected overlays', 6)
 
+        result = 0
+
         for i in self.selection:
             overlay = self.db.select(i)
 
@@ -204,8 +219,12 @@ class Delete:
                 except Exception, error:
                     OUT.warn('Failed to delete overlay "' + i + '".\nError was: '
                              + str(error), 2)
+                    result = 1
             else:
                 OUT.warn('Overlay "' + i + '" does not exist!', 2)
+                result = 1
+
+        return result
 
 #===============================================================================
 #
@@ -231,6 +250,7 @@ class List:
     >>> OUT.color_off()
     >>> a.run()
     * wrobel                    [Subversion] (source: https://overlays.gentoo.or...)
+    0
     >>> a.config['verbose'] = True
     >>> a.run()
     * wrobel
@@ -253,6 +273,7 @@ class List:
     * Description:
     *   A collection of ebuilds from Gunnar Wrobel [wrobel@gentoo.org].
     * 
+    0
     '''
 
     def __init__(self, config):
@@ -289,6 +310,8 @@ class List:
                               'll this overlay ***\n')
                 OUT.error(i[0])
 
+        return 0
+
 #===============================================================================
 #
 # Class ListLocal
@@ -332,6 +355,8 @@ class ListLocal:
                               'll this overlay ***\n')
                 OUT.error(i[0])
 
+        return 0
+
 #===============================================================================
 #
 # Class Actions
@@ -362,13 +387,21 @@ class Actions:
                     Fetch(config).run()
                     break
 
+        result = 0
+
         for i in self.actions:
 
             OUT.debug('Checking for action', 7)
 
             if i[0] in config.keys():
-                i[1](config).run()
+                result += i[1](config).run()
 
+
+        if not result:
+            sys.exit(0)
+        else:
+            sys.exit(1)
+            
 #===============================================================================
 #
 # Testing
