@@ -16,7 +16,7 @@
 #
 '''Defines the configuration options and provides parsing functionality.'''
 
-__version__ = "$Id: config.py 273 2006-12-30 15:54:50Z wrobel $"
+__version__ = "$Id: config.py 286 2007-01-09 17:48:23Z wrobel $"
 
 #===============================================================================
 #
@@ -52,7 +52,7 @@ class Config(object):
         >>> a['overlays']
         '\\nhttp://www.gentoo.org/proj/en/overlays/layman-global.txt'
         >>> sorted(a.keys())
-        ['cache', 'config', 'config_dir', 'local_list', 'make_conf', 'nocheck', 'overlays', 'proxy', 'storage']
+        ['cache', 'config', 'config_dir', 'local_list', 'make_conf', 'nocheck', 'overlays', 'proxy', 'quietness', 'storage']
         '''
 
         self.defaults = {'config_dir': '/etc/layman',
@@ -125,6 +125,14 @@ class Config(object):
                          action = 'store_true',
                          help = 'Do not fetch a remote list of overlays.')
 
+        group.add_option('-p',
+                         '--priority',
+                         action = 'store',
+                         help = 'Use this with the --add switch to set the prior'
+                         'ity of the added overlay. This will influence the sort'
+                         'ing order of the overlays in the PORTDIR_OVERLAY varia'
+                         'ble.')
+
         self.parser.add_option_group(group)
 
         #-----------------------------------------------------------------
