@@ -16,7 +16,7 @@
 #
 '''Handles different storage files.'''
 
-__version__ = "$Id: db.py 286 2007-01-09 17:48:23Z wrobel $"
+__version__ = "$Id: db.py 309 2007-04-09 16:23:38Z wrobel $"
 
 #===============================================================================
 #
@@ -24,7 +24,7 @@ __version__ = "$Id: db.py 286 2007-01-09 17:48:23Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import os, os.path, urllib, re, md5
+import os, os.path, urllib2, re, md5
 
 from   layman.utils             import path
 from   layman.overlay           import Overlays
@@ -211,7 +211,14 @@ class RemoteDB(Overlays):
         self.proxies = {}
 
         if config['proxy']:
-            self.proxies['http']  = config['proxy']
+            self.proxies['http'] = config['proxy']
+        elif os.getenv('http_proxy'):
+            self.proxies['http'] = os.getenv('http_proxy')
+
+        if self.proxies:
+	    proxy_handler = urllib2.ProxyHandler(self.proxies)
+	    opener = urllib2.build_opener(proxy_handler)
+	    urllib2.install_opener(opener)
 
         self.urls  = [i.strip() for i in config['overlays'].split('\n') if i]
 
@@ -257,7 +264,7 @@ class RemoteDB(Overlays):
             try:
 
                 # Fetch the remote list
-                olist = urllib.urlopen(url, proxies = self.proxies).read()
+                olist = urllib2.urlopen(url).read()
 
                 # Create our storage directory if it is missing
                 if not os.path.exists(os.path.dirname(mpath)):
