@@ -16,7 +16,7 @@
 #
 ''' Basic overlay class.'''
 
-__version__ = "$Id: overlay.py 238 2006-09-05 21:40:31Z wrobel $"
+__version__ = "$Id: overlay.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -24,7 +24,7 @@ __version__ = "$Id: overlay.py 238 2006-09-05 21:40:31Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import re, os, os.path, shutil
+import re, os, os.path, shutil, popen2
 
 from   layman.utils             import node_to_dict, dict_to_node, path
 
@@ -41,7 +41,7 @@ class Overlay:
 
     type = 'None'
 
-    def __init__(self, xml, ignore = 0):
+    def __init__(self, xml, ignore = 0, quiet = False):
         '''
         >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> document = open(here + '/../tests/testfiles/global-overlays.xml').read()
@@ -65,6 +65,7 @@ class Overlay:
         >>> b.is_official()
         False
         '''
+        self.quiet = quiet
 
         self.data = node_to_dict(xml)
 
@@ -88,7 +89,7 @@ class Overlay:
 				'"contact" attribute!')
             elif ignore == 1:
                 OUT.warn('Overlay "' + self.name + '" is missing a '
-                         '"contact" attribute!')
+                         '"contact" attribute!', 4)
 
         if '<description>1' in self.data.keys():
             self.description = self.data['<description>1']['@'].strip()
@@ -99,7 +100,7 @@ class Overlay:
 				'"description" entry!')
             elif ignore == 1:
                 OUT.warn('Overlay "' + self.name + '" is missing a '
-			 '"description" entry!')
+			 '"description" entry!', 4)
 
         if '&status' in self.data.keys():
             self.status = self.data['&status']
@@ -144,9 +145,18 @@ class Overlay:
     def cmd(self, command):
         '''Run a command.'''
 
-        OUT.info('Running command "' + command + '"...', 1)
+        OUT.info('Running command "' + command + '"...', 2)
 
-        return os.system(command)
+        if not self.quiet:
+            return os.system(command)
+        else:
+            cmd = popen2.Popen4(command)
+            cmd.fromchild.readlines()
+            result = cmd.wait()
+            cmd.fromchild.readlines()
+            cmd.fromchild.close()
+            cmd.tochild.close()
+            return result
 
     def __str__(self):
         '''
