@@ -16,7 +16,7 @@
 #
 ''' Tar overlay support.'''
 
-__version__ = "$Id: tar.py 285 2007-01-05 08:49:14Z wrobel $"
+__version__ = "$Id: tar.py 310 2007-04-09 16:30:40Z wrobel $"
 
 #===============================================================================
 #
@@ -24,7 +24,7 @@ __version__ = "$Id: tar.py 285 2007-01-05 08:49:14Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import os, os.path, sys, urllib, shutil
+import os, os.path, sys, urllib2, shutil
 
 from   layman.utils             import path
 from   layman.overlays.overlay  import Overlay
@@ -46,7 +46,7 @@ class TarOverlay(Overlay):
     ...   def __init__(self):
     ...     self.name = 'dummy'
     ...     here = os.path.dirname(os.path.realpath(__file__))
-    ...     self.src  = here + '/../tests/testfiles/layman-test.tar.bz2'
+    ...     self.src  = 'file://' + here + '/../tests/testfiles/layman-test.tar.bz2'
     ...     self.subpath = 'layman-test'
     ...     self.format = 'bz2'
     ...     self.quiet = False
@@ -110,7 +110,7 @@ class TarOverlay(Overlay):
 
         try:
 
-            tar = urllib.urlopen(self.src).read()
+            tar = urllib2.urlopen(self.src).read()
 
         except Exception, error:
             raise Exception('Failed to fetch the tar package from: '
